from label import Label
from frame import Frame
from geo import Vect
from box import Box, AbsBox
from button import Button
from window import Window
from widget import Widget
from scrollable import Scrollable
from tichy.text import Text
from tichy.tasklet import Wait
from tichy.service import Service
from tichy.actor import Actor
from tichy.menu import Menu

from tichy.application import Application

class ActionBar(Widget):
    def __init__(self, parent):
        super(ActionBar, self).__init__(parent, min_size = Vect(480, 0), modal = False)
        scrollable = Scrollable(self, axis = 0)
        self.box = Box(scrollable, axis = 0, border = 0, spacing = 0)
        self.buttons = []
        self.selected_view = None
        
    def clear(self):
        if self.selected_view:
            self.selected_view.selected = False
            self.selected_view = None
        for b in self.buttons:
            b.destroy()
            
    def set_actor(self, actor, view):
        if self.selected_view == view:
            self.clear()
            return
    
        self.clear()
        
        self.selected_view = view
        view.selected = True
        for a in actor.actions:
            b = Button(self.box)
            Label(b, a.name)
            def on_clicked(b, a):
                # self.clear()
                a.activate(b)
            b.connect('clicked', on_clicked, a)
            self.buttons.append(b)

class ApplicationFrame(Frame):
    icon = None
    class Bar(Frame):
        class BackButton(Button):
            pass
            
        def __init__(self, parent, app, back_button = False, **kargs):
            self.app = app
            super(ApplicationFrame.Bar, self).__init__(parent, min_size = Vect(0, 96), **kargs)
            box = Box(self, axis = 0)
            app.actor.view(box, expandable=True)
            if back_button:
                msg = "back" if back_button is True else back_button 
                back = ApplicationFrame.Bar.BackButton(box, min_size=Vect(0,0))
                Label(back, msg)
                back.connect('clicked', self.on_back)
        def on_back(self, b):
            self.app.emit('back')
            
    class Content(Frame):
        def __init__(self, parent):
            super(ApplicationFrame.Content, self).__init__(parent, min_size = Vect(480, 0), expandable = True)
            
    def get_text(self):
        return Text(self.title)
        
    def path(self, file_name = None):
        return self.app.path(file_name)
         
    def __init__(self, parent, app, title = None, border = 0, back_button = False, **kargs):
        import tichy.item as item
        
        assert isinstance(app, Application), app
        self.app = app
        
        super(ApplicationFrame, self).__init__(parent, border = 0, **kargs)
        self.title = title or app.name
        self.icon = app.icon
        self.content = self
        self.box = Box(self, axis = 1, border = 0, spacing = 0)
        # self.bar = ApplicationFrame.Bar(self.box, title = title)
        self.actor = Actor(self)
        
        self.bar = ApplicationFrame.Bar(self.box, self, back_button=back_button)
        self.content = ApplicationFrame.Content(self.box)
        
        self.action_bar = ActionBar(self.box)
        self.menu = Menu()
        
        self.menu.connect('activated', self.on_bar_clicked, None)
        
        self.menu_view = None
        # self.bar.connect("mouse-down", self.on_bar_clicked)
        
    def get_contents_child(self):
        return self.content
        
    def on_bar_clicked(self, b, pos):
        if self.menu_view:
            self.menu_view.destroy()
            self.menu_view = None
        else:
            self.menu_view = Box(self.window, border = 0, axis = 1, spacing = 0)
            Widget(self.menu_view, min_size = self.bar.min_size)
            self.menu.view(self.menu_view)

            
